| Title: | Data from the Doctor Who Series |
|---|---|
| Description: | Explore data related to the Doctor Who TV series. |
| Authors: | Jonathan Kitt [aut, cre] |
| Maintainer: | Jonathan Kitt <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.0.5 |
| Built: | 2026-05-18 06:38:57 UTC |
| Source: | https://github.com/kittjonathan/datardis |
List of directors for all episodes from the revived Doctor Who era (2005-present)
drwho_directorsdrwho_directors
This data frame contains the following columns:
story_numberStory number
directorEpisode's director
https://en.wikipedia.org/wiki/List_of_Doctor_Who_episodes_(2005-present)
library(dplyr) drwho_directors |> count(director, sort = TRUE) |> head(5)library(dplyr) drwho_directors |> count(director, sort = TRUE) |> head(5)
List of all episodes from the revived Doctor Who era (2005-present)
drwho_episodesdrwho_episodes
This data frame contains the following columns:
era"classic" or "revived"
season_numberSeason number
serial_titleSerial title if available
story_numberStory number
episode_numberEpisode number in season
episode_titleEpisode Title
type"episode" or "special"
first_airedDate the episode first aired in the U.K.
production_codeEpisode's production code if available
uk_viewersNumber of U.K. viewers (millions)
ratingEpisode's rating
durationEpisode's duration in minutes
https://en.wikipedia.org/wiki/List_of_Doctor_Who_episodes_(2005-present)
library(dplyr) drwho_episodes |> filter(type == "special")library(dplyr) drwho_episodes |> filter(type == "special")
List of writers for all episodes from the revived Doctor Who era (2005-present)
drwho_writersdrwho_writers
This data frame contains the following columns:
story_numberStory number
writerEpisode's writer
https://en.wikipedia.org/wiki/List_of_Doctor_Who_episodes_(2005-present)
library(dplyr) drwho_writers |> count(writer, sort = TRUE) |> head(5)library(dplyr) drwho_writers |> count(writer, sort = TRUE) |> head(5)
List of directors for all episodes from Torchwood series (2006-2011)
torchwood_directorstorchwood_directors
This data frame contains the following columns:
story_numberStory number
directorEpisode's director
https://en.wikipedia.org/wiki/List_of_Torchwood_episodes
library(dplyr) torchwood_directors |> count(director) |> arrange(desc(n)) |> head(5)library(dplyr) torchwood_directors |> count(director) |> arrange(desc(n)) |> head(5)
List of all episodes from the Torchwood series (2006-2011)
torchwood_episodestorchwood_episodes
This data frame contains the following columns:
season_numberSeason number
serial_titleSerial title if available
story_numberStory number
episode_numberEpisode number in season
episode_titleEpisode Title
first_airedDate the episode first aired in the U.K.
production_codeEpisode's production code if available
uk_viewersNumber of U.K. viewers (millions)
durationEpisode's duration in minutes
https://en.wikipedia.org/wiki/List_of_Torchwood_episodes
library(dplyr) torchwood_episodes |> filter(uk_viewers >= 5)library(dplyr) torchwood_episodes |> filter(uk_viewers >= 5)
List of directors for all episodes from Torchwood series (2006-2011)
torchwood_writerstorchwood_writers
This data frame contains the following columns:
story_numberStory number
writerEpisode's writer
https://en.wikipedia.org/wiki/List_of_Torchwood_episodes
library(dplyr) torchwood_writers |> count(writer, sort = TRUE) |> head(5)library(dplyr) torchwood_writers |> count(writer, sort = TRUE) |> head(5)